package Net::Async::Slack::Event::ManualPresenceChange;

use strict;
use warnings;

our $VERSION = '0.003'; # VERSION

use Net::Async::Slack::EventType;

=head1 NAME

Net::Async::Slack::Event::ManualPresenceChange - You manually updated your presence

=head1 DESCRIPTION

Example input data:

    {
        "type": "manual_presence_change",
        "presence": "away"
    }


=cut

sub type { 'manual_presence_change' }

1;

__END__

=head1 AUTHOR

Tom Molesworth <TEAM@cpan.org>

=head1 LICENSE

Copyright Tom Molesworth 2016-2019. Licensed under the same terms as Perl itself.
